@@ -245,6 +245,14 @@ def del_key(key):
     if not data[section]:
         del data[section]
 
+def del_section(section):
+    global data, _watches, _blocked_watches
+    #FIXME watches
+    if section not in data:
+        # Trying to delete a deleted section
+        return
+    del data[section]
+
 ######################################
 ## reading and writing the database ##
 ######################################
