@@ -48,8 +48,7 @@ class Teacher(abstract.LessonbasedTeacher):
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
-                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG) \
-                and (not self.get_bool('one_chance_only')):
+                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
             return Teacher.ERR_PICKY
 
         self.m_is_first_question = self.q_status == const.QSTATUS_NO
@@ -187,8 +186,6 @@ class Gui(abstract.Gui):
         frame.add(vbox)
         vbox.pack_start(gu.nCheckButton(self.m_exname,
                     "warning_sound", _("Play warning sound")))
-        vbox.pack_start(gu.nCheckButton(self.m_exname, "one_chance_only",
-                  _("Only one chance to get the answer right")))
         self.config_box.pack_start(frame, False)
         self.config_box.show_all()
         ##############
@@ -234,22 +231,15 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     self.flash_and_play_first_tone()
                     return
                 self.g_flashbar.flash(_("Wrong"))
-                if self.get_bool('one_chance_only'):
-                    self.m_t.new_question()
-                    if self.get_bool("warning_sound"):
+                self.g_give_up.set_sensitive(True)
+                if self.get_bool("warning_sound"):
+                    if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                         self.m_t.spank_me_play_question()
                     else:
-                        self.m_t.play_question()
+                        self.m_t.spank_me()
                 else:
-                    self.g_give_up.set_sensitive(True)
-                    if self.get_bool("warning_sound"):
-                        if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
-                            self.m_t.spank_me_play_question()
-                        else:
-                            self.m_t.spank_me()
-                    else:
-                        if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
-                            self.m_t.play_question()
+                    if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
+                        self.m_t.play_question()
         self.set_percentage_label()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
