@@ -586,10 +586,13 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
                    ['practise', 'config', 'statistics'].index(urlobj.action))
             else:
                 self.box_dict[self.m_viewer].g_notebook.set_current_page(0)
-        if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
-            self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
+        if self.box_dict[module].m_t.m_P:
+            if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
+                self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
+            else:
+                self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
         else:
-            self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
+            self.set_title("Solfege")
     def _show_docviewer(self):
         if 'docviewer' not in self.box_dict:
             self.box_dict['docviewer'] = DocViewer(self.m_app.handle_href)
